<!-- DOCTOC SKIP -->
# Changelog

## [2.0.0](https://github.com/City-of-Helsinki/django-resilient-logger/compare/v1.2.0...v2.0.0) (2026-02-11)


### ⚠ BREAKING CHANGES

* Tasks that previously ran by default are now disabled. If some project relied on default values, those configurations must be updated to enable the cron tasks explicitly.

### Features

* Add better config validations ([a6afd1f](https://github.com/City-of-Helsinki/django-resilient-logger/commit/a6afd1fe8a3667149bc33d54b42fd4f3ac36edd4))
* Change default task enabled states ([98ceb4f](https://github.com/City-of-Helsinki/django-resilient-logger/commit/98ceb4fac7c5bd7896f95a5d561fd084d4205e51))

## [1.2.0](https://github.com/City-of-Helsinki/django-resilient-logger/compare/v1.1.1...v1.2.0) (2025-12-16)


### Features

* Use elasticsearch8 as a requirement ([ba65a8a](https://github.com/City-of-Helsinki/django-resilient-logger/commit/ba65a8a80aaf67736109886bcb6b627bef65f051))

## [1.1.1](https://github.com/City-of-Helsinki/django-resilient-logger/compare/v1.1.0...v1.1.1) (2025-11-28)


### Bug Fixes

* Add missing super calls ([be3dc29](https://github.com/City-of-Helsinki/django-resilient-logger/commit/be3dc2973659515762329e107a30ccbdc6c5779b))

## [1.1.0](https://github.com/City-of-Helsinki/django-resilient-logger/compare/v1.0.0...v1.1.0) (2025-11-25)


### Features

* Support bulk create for ResilientLogSource ([aeab1d9](https://github.com/City-of-Helsinki/django-resilient-logger/commit/aeab1d930cad52ac35056920ec4f947acfd079ad))


### Bug Fixes

* **readme:** Update instructions for development requirements ([173c521](https://github.com/City-of-Helsinki/django-resilient-logger/commit/173c521a44104353e5faebac6564d4aef8f3ee90))

## [1.0.0](https://github.com/City-of-Helsinki/django-resilient-logger/compare/v0.3.7...v1.0.0) (2025-11-12)


### Features

* Add source_pk as audit event extra ([425c621](https://github.com/City-of-Helsinki/django-resilient-logger/commit/425c621b9aae00155e85ec23ecdeb988884a904d))


### Dependencies

* Update python and django version support ([f7fe1af](https://github.com/City-of-Helsinki/django-resilient-logger/commit/f7fe1afe65e16020a83d401cb6eeb2a8e04033fc))


### Documentation

* Update README to include AUDIT_LOG_ENV ([7ae721a](https://github.com/City-of-Helsinki/django-resilient-logger/commit/7ae721a26e44378490213fd4f161857c9278ebcf))
